@@ -27,26 +27,26 @@ UNREALIZABLE_REFSPECS="trivial_un.spc"
 if test $VERBOSE -eq 1; then
     echo "\nChecking specifications that should be realizable..."
 fi
-for k in `echo $REFSPECS`; do
+for k in $(echo $REFSPECS); do
     if test $VERBOSE -eq 1; then
-	echo "\t gr1c -r $TESTDIR/specs/$k"
+        echo "\t gr1c -r $TESTDIR/specs/$k"
     fi
     if ! $BUILD_ROOT/gr1c -r specs/$k > /dev/null; then
-	echo $PREFACE "realizable specs/${k} detected as unrealizable\n"
-	exit -1
+        echo $PREFACE "realizable specs/${k} detected as unrealizable\n"
+        exit 1
     fi
 done
 
 if test $VERBOSE -eq 1; then
     echo "\nChecking specifications that should be unrealizable..."
 fi
-for k in `echo $UNREALIZABLE_REFSPECS`; do
+for k in $(echo $UNREALIZABLE_REFSPECS); do
     if test $VERBOSE -eq 1; then
-	echo "\t gr1c -r $TESTDIR/specs/$k"
+        echo "\t gr1c -r $TESTDIR/specs/$k"
     fi
     if $BUILD_ROOT/gr1c -r specs/$k > /dev/null; then
-	echo $PREFACE "unrealizable specs/${k} detected as realizable\n"
-	exit -1
+        echo $PREFACE "unrealizable specs/${k} detected as realizable\n"
+        exit 1
     fi
 done
 
@@ -57,7 +57,7 @@ if test $VERBOSE -eq 1; then
 fi
 if $BUILD_ROOT/gr1c -r -n ALL_INIT specs/trivial_partwin.spc > /dev/null; then
     echo $PREFACE "unrealizable specs/trivial_partwin.spc with init_flags ALL_INIT detected as realizable\n"
-    exit -1
+    exit 1
 fi
 
 
@@ -70,18 +70,20 @@ REFSPECS="trivial_2var.spc free_counter.spc count_onestep.spc trivial_mustblock.
 if test $VERBOSE -eq 1; then
     echo "\nPerforming regression tests for vanilla GR(1) synthesis..."
 fi
-for k in `echo $REFSPECS`; do
+for k in $(echo $REFSPECS); do
     if test $VERBOSE -eq 1; then
-	echo "\tComparing  gr1c -t txt $TESTDIR/specs/$k \n\t\tagainst $TESTDIR/expected_outputs/${k}.listdump.out"
+        echo "\tComparing  gr1c -t txt $TESTDIR/specs/$k \n\t\tagainst $TESTDIR/expected_outputs/${k}.listdump.out"
     fi
     if ! ($BUILD_ROOT/gr1c -t txt specs/$k | cmp -s expected_outputs/${k}.listdump.out -); then
-	echo $PREFACE "synthesis regression test failed for specs/${k}\n"
-	exit -1
+        echo $PREFACE "synthesis regression test failed for specs/${k}\n"
+        exit 1
     fi
 done
 
 
-# Testing init_flags besides ALL_ENV_EXIST_SYS_INIT
+if test $VERBOSE -eq 1; then
+    echo "\nRegression tests for GR(1) synthesis with other init_flags..."
+fi
 for q in ALL_INIT; do
     for k in count_onestep.spc; do
         if test $VERBOSE -eq 1; then
@@ -89,12 +91,46 @@ for q in ALL_INIT; do
         fi
         if ! ($BUILD_ROOT/gr1c -n ${q} -t txt specs/$k | cmp -s expected_outputs/${k}.${q}.listdump.out -); then
             echo $PREFACE "synthesis regression test failed for specs/${k} with init_flags ${q}\n"
-            exit -1
+            exit 1
         fi
     done
 done
 
 
+################################################################
+# Checking output formats
+
+if test $VERBOSE -eq 1; then
+    echo "\nChecking syntax for examples of DOT output..."
+fi
+if ! (dot -V > /dev/null); then
+    echo $PREFACE "GraphViz dot not installed. Tests require it to check DOT syntax.\n"
+    exit 1
+fi
+if ! ($BUILD_ROOT/gr1c -t dot specs/trivial_2var.spc | dot -Tsvg > /dev/null); then
+    echo $PREFACE "syntax error in DOT output from gr1c on specs/trivial_2var.spc\n"
+    exit 1
+fi
+
+if test $VERBOSE -eq 1; then
+    echo "\nChecking syntax for examples of JSON output..."
+fi
+if ! (python -V > /dev/null 2>&1); then
+    if ! (python3 -V > /dev/null); then
+        echo $PREFACE "Python not installed. Tests require it to check JSON syntax.\n"
+        exit 1
+    else
+        PYTHON=python3
+    fi
+else
+    PYTHON=python
+fi
+if ! ($BUILD_ROOT/gr1c -t json specs/trivial_2var.spc | $PYTHON -m json.tool > /dev/null); then
+    echo $PREFACE "syntax error in JSON output from gr1c on specs/trivial_2var.spc\n"
+    exit 1
+fi
+
+
 ################################################################
 # Reachability game synthesis regression tests
 
@@ -103,13 +139,13 @@ REFSPECS="reach_2var.spc reach_2var_mustblock.spc reach_free_counter.spc reach_f
 if test $VERBOSE -eq 1; then
     echo "\nPerforming regression tests for reachability games..."
 fi
-for k in `echo $REFSPECS`; do
+for k in $(echo $REFSPECS); do
     if test $VERBOSE -eq 1; then
-	echo "\tComparing  rg -t txt $TESTDIR/specs/$k \n\t\tagainst $TESTDIR/expected_outputs/${k}.listdump.out"
+        echo "\tComparing  gr1c-rg -t txt $TESTDIR/specs/$k \n\t\tagainst $TESTDIR/expected_outputs/${k}.listdump.out"
     fi
-    if ! ($BUILD_ROOT/rg -t txt specs/$k | cmp -s expected_outputs/${k}.listdump.out -); then
-	echo $PREFACE "Reachability game synthesis regression test failed for specs/${k}\n"
-	exit -1
+    if ! ($BUILD_ROOT/gr1c-rg -t txt specs/$k | cmp -s expected_outputs/${k}.listdump.out -); then
+        echo $PREFACE "Reachability game synthesis regression test failed for specs/${k}\n"
+        exit 1
     fi
 done
 
@@ -122,13 +158,13 @@ REFSPECS="trivial_partwin gridworld_bool"
 if test $VERBOSE -eq 1; then
     echo "\nPerforming regression tests for interaction..."
 fi
-for k in `echo $REFSPECS`; do
+for k in $(echo $REFSPECS); do
     if test $VERBOSE -eq 1; then
-	echo "\tComparing gr1c -i $TESTDIR/specs/${k}.spc < $TESTDIR/interaction_scripts/${k}_IN.txt \n\t\tagainst $TESTDIR/interaction_scripts/${k}_OUT.txt"
+        echo "\tComparing  gr1c -i $TESTDIR/specs/${k}.spc < $TESTDIR/interaction_scripts/${k}_IN.txt \n\t\tagainst $TESTDIR/interaction_scripts/${k}_OUT.txt"
     fi
     if ! $BUILD_ROOT/gr1c -i specs/${k}.spc < interaction_scripts/${k}_IN.txt | diff - interaction_scripts/${k}_OUT.txt > /dev/null; then
         echo $PREFACE "unexpected behavior in scripted interaction using specs/${k}\n"
-        exit -1
+        exit 1
     fi
 done
 
@@ -139,13 +175,13 @@ done
 if test $VERBOSE -eq 1; then
     echo "\nChecking detection of flawed specification files..."
 fi
-for k in `ls flawed_specs/*.spc`; do
+for k in $(ls flawed_specs/*.spc); do
     if test $VERBOSE -eq 1; then
-	echo "\t gr1c -s $k"
+        echo "\t gr1c -s $k"
     fi
     if $BUILD_ROOT/gr1c -s $k > /dev/null 2>&1; then
-	echo $PREFACE "Flawed ${k} detected as OK\n"
-	exit -1
+        echo $PREFACE "Flawed ${k} detected as OK\n"
+        exit 1
     fi
 done
 
@@ -156,12 +192,12 @@ done
 if test $VERBOSE -eq 1; then
     echo "\nChecking detection of flawed reachability game (rg) specification files..."
 fi
-for k in `ls flawed_reach_specs/*.spc`; do
+for k in $(ls flawed_reach_specs/*.spc); do
     if test $VERBOSE -eq 1; then
-	echo "\t gr1c -s $k"
+        echo "\t gr1c-rg -s $k"
     fi
-    if $BUILD_ROOT/rg -s $k > /dev/null 2>&1; then
-	echo $PREFACE "Flawed reachability game spec ${k} detected as OK\n"
-	exit -1
+    if $BUILD_ROOT/gr1c-rg -s $k > /dev/null 2>&1; then
+        echo $PREFACE "Flawed reachability game spec ${k} detected as OK\n"
+        exit 1
     fi
 done
